function love.load()
    love.graphics.setBackgroundColor(0, 0, 0)

    shader = love.graphics.newShader([[
    #define P 0.0001 //derivative precision
    #define SIZE vec2(8, 6) //function size/precision
    #define WATER vec4(1) //water color

    float func(vec2 coords, float offset) {
      return (sin(coords.x - offset) * sin(coords.y + offset) + 1) / 2;
      //return (sin(coords.x - offset) + 1) / 2;
      //return cos(sqrt(pow(coords.x + offset, 2.0) + pow(coords.y + offset, 2.0)));
    }

    float xDerivative(vec2 coords, float offset) {
      return (func(coords + vec2(P, 0), offset) - func(coords - vec2(P, 0), offset))/((coords.x + P) - (coords.x - P));
    }

    float yDerivative(vec2 coords, float offset) {
      return (func(coords + vec2(0, P), offset) - func(coords - vec2(0, P), offset))/((coords.y + P) - (coords.y - P));
    }

    uniform float time = 0;

    vec4 effect(vec4 color, Image image, vec2 texCoords, vec2 scrCoords) {
      float waveHeight = func(texCoords * SIZE, time);

      float xDerivative = xDerivative(texCoords * SIZE, time);
      float yDerivative = yDerivative(texCoords * SIZE, time);

      vec2 off;
      off.x = xDerivative * waveHeight / SIZE.x;
      off.y = yDerivative * waveHeight / SIZE.y;

      //return vec4(xDerivative, yDerivative, 0, 1);
      //return vec4(waveHeight, 0, 0, 1);
      return Texel(image, texCoords + off) * WATER;
    }
    ]])

    images = {"bg.jpg", "bg.png", "bg2.jpg"}
    image = love.graphics.newImage(images[1])

    timer = 0

    canvas = love.graphics.newCanvas(800, 600)

    love.graphics.setCanvas(canvas)
        love.graphics.setColor(1, 1, 1, 1)
        love.graphics.rectangle("fill", 0, 0, 800, 600)

        love.graphics.setColor(0, 0, 0, 1)
        for x = 0, 800, 50 do
            love.graphics.line(x, 0, x, 600)
        end
        for y = 0, 600, 50 do
            love.graphics.line(0, y, 800, y)
        end
    love.graphics.setCanvas()
end

function love.update(dt)
    timer = timer + dt
end

function love.draw()
    shader:send("time", timer)
    love.graphics.setShader(shader)
    --love.graphics.draw(image)
    love.graphics.draw(canvas)
    love.graphics.setShader()
end

function loadShader(fileName)
    local file = io.open(fileName)
    local shaderCode = file:read("*all")
    file:close()

    return shaderCode
end
